ControlledInput class

Input widget for uploading media with text

Inheritance

Constructors

ControlledInput({Key? key, required void setMediaSelectionsWithText(String text), String? initialText, required void onSubmitted()})
Input for adding text to selected media
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialText → String?
Optional Initial text passed to the input
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSubmitted → void Function()
Callback for handling onSubmit of picked media with text
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setMediaSelectionsWithText → void Function(String text)
Callback to handle setting the media selected with the input text
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ControlledInput>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited